@@ -416,8 +416,8 @@ class ConfigManager(object):
                 _cfgstore['main'] = {}
                 self._bg_sync_to_file()
             self._cfgstore = _cfgstore['main']
-            if 'groups' not in self._cfgstore:
-                self._cfgstore['groups'] = {'everything': {'nodes': set()}}
+            if 'nodegroups' not in self._cfgstore:
+                self._cfgstore['nodegroups'] = {'everything': {'nodes': set()}}
                 self._bg_sync_to_file()
             if 'nodes' not in self._cfgstore:
                 self._cfgstore['nodes'] = {}
@@ -431,8 +431,8 @@ class ConfigManager(object):
             self._bg_sync_to_file()
         self.tenant = tenant
         self._cfgstore = _cfgstore['tenant'][tenant]
-        if 'groups' not in self._cfgstore:
-            self._cfgstore['groups'] = {'everything': {}}
+        if 'nodegroups' not in self._cfgstore:
+            self._cfgstore['nodegroups'] = {'everything': {}}
         if 'nodes' not in self._cfgstore:
             self._cfgstore['nodes'] = {}
         self._bg_sync_to_file()
@@ -534,6 +534,41 @@ class ConfigManager(object):
         except KeyError:
             return None
 
+    def get_usergroup(self, groupname):
+        """Get user group information from DB
+
+        :param groupname: Name of the group
+
+        Returns a dictionary describing parameters of a user group.
+        This may include the role for users in the group to receive
+        if no more specific information is found.
+
+        """
+        try:
+            return copy.deepcopy(self._cfgstore['usergroups'][groupname])
+        except KeyError:
+            return None
+
+    def set_usergroup(self, groupname, attributemap):
+        """Set usergroup attribute(s)
+
+        :param groupname: the name of teh group to modify
+        :param attributemap: The mapping of keys to values to set
+        """
+
+        for attribute in attributemap.iterkeys():
+            self._cfgstore['usergroups'][attribute] = attributemap[attribute]
+        _mark_dirtykey('usergroups', groupname, self.tenant)
+
+    def create_usergroup(selfself, groupname, role="Administrator"):
+        if 'usergroups' not in self._cfgstore:
+            self._cfgstore['usergroups'] = {}
+        groupname = groupname.encode('utf-8')
+        if groupname in self._cfgstore['usergroups']:
+            raise Exception("Duplicate groupname requested")
+        self._cfgstore['usergroups'][groupname] = {'role': role}
+        _mark_dirtykey('usergroups', groupname, self.tenant)
+
     def set_user(self, name, attributemap):
         """Set user attribute(s)
 
@@ -542,7 +577,7 @@ class ConfigManager(object):
         """
         user = self._cfgstore['users'][name]
         for attribute in attributemap:
-            if attribute == 'passphrase':
+            if attribute == 'password':
                 salt = os.urandom(8)
                 #TODO: WORKERPOOL, offload password set to a worker
                 crypted = KDF.PBKDF2(
@@ -602,10 +637,10 @@ class ConfigManager(object):
         return node in self._cfgstore['nodes']
 
     def is_nodegroup(self, nodegroup):
-        return nodegroup in self._cfgstore['groups']
+        return nodegroup in self._cfgstore['nodegroups']
 
     def get_groups(self):
-        return self._cfgstore['groups'].iterkeys()
+        return self._cfgstore['nodegroups'].iterkeys()
 
     def list_nodes(self):
         try:
@@ -614,7 +649,7 @@ class ConfigManager(object):
             return []
 
     def get_nodegroup_attributes(self, nodegroup, attributes=()):
-        cfgnodeobj = self._cfgstore['groups'][nodegroup]
+        cfgnodeobj = self._cfgstore['nodegroups'][nodegroup]
         if not attributes:
             attributes = cfgnodeobj.iterkeys()
         nodeobj = {}
@@ -655,7 +690,7 @@ class ConfigManager(object):
     def _node_added_to_group(self, node, group, changeset):
         try:
             nodecfg = self._cfgstore['nodes'][node]
-            groupcfg = self._cfgstore['groups'][group]
+            groupcfg = self._cfgstore['nodegroups'][group]
         except KeyError:  # something did not exist, nothing to do
             return
         for attrib in groupcfg.iterkeys():
@@ -696,12 +731,12 @@ class ConfigManager(object):
         if not 'groups' in nodecfg:
             return
         for group in nodecfg['groups']:
-            if attrib in self._cfgstore['groups'][group]:
+            if attrib in self._cfgstore['nodegroups'][group]:
                 if srcgroup is not None and group != srcgroup:
                     # skip needless deepcopy
                     return
                 nodecfg[attrib] = \
-                    copy.deepcopy(self._cfgstore['groups'][group][attrib])
+                    copy.deepcopy(self._cfgstore['nodegroups'][group][attrib])
                 nodecfg[attrib]['inheritedfrom'] = group
                 self._refresh_nodecfg(nodecfg, attrib, nodename,
                                       changeset=changeset)
@@ -712,19 +747,19 @@ class ConfigManager(object):
                 return
 
     def _sync_groups_to_node(self, groups, node, changeset):
-        for group in self._cfgstore['groups'].iterkeys():
+        for group in self._cfgstore['nodegroups'].iterkeys():
             if group not in groups:
-                if node in self._cfgstore['groups'][group]['nodes']:
-                    self._cfgstore['groups'][group]['nodes'].discard(node)
+                if node in self._cfgstore['nodegroups'][group]['nodes']:
+                    self._cfgstore['nodegroups'][group]['nodes'].discard(node)
                     self._node_removed_from_group(node, group, changeset)
-                    _mark_dirtykey('groups', group, self.tenant)
+                    _mark_dirtykey('nodegroups', group, self.tenant)
         for group in groups:
-            if group not in self._cfgstore['groups']:
-                self._cfgstore['groups'][group] = {'nodes': set([node])}
-                _mark_dirtykey('groups', group, self.tenant)
-            elif node not in self._cfgstore['groups'][group]['nodes']:
-                self._cfgstore['groups'][group]['nodes'].add(node)
-                _mark_dirtykey('groups', group, self.tenant)
+            if group not in self._cfgstore['nodegroups']:
+                self._cfgstore['nodegroups'][group] = {'nodes': set([node])}
+                _mark_dirtykey('nodegroups', group, self.tenant)
+            elif node not in self._cfgstore['nodegroups'][group]['nodes']:
+                self._cfgstore['nodegroups'][group]['nodes'].add(node)
+                _mark_dirtykey('nodegroups', group, self.tenant)
             # node was not already in given group, perform inheritence fixup
             self._node_added_to_group(node, group, changeset)
 
@@ -751,7 +786,7 @@ class ConfigManager(object):
     def set_group_attributes(self, attribmap, autocreate=False):
         changeset = {}
         for group in attribmap.iterkeys():
-            if not autocreate and group not in self._cfgstore['groups']:
+            if not autocreate and group not in self._cfgstore['nodegroups']:
                 raise ValueError("{0} group does not exist".format(group))
             for attr in attribmap[group].iterkeys():
                 if (attr != 'nodes' and
@@ -771,9 +806,9 @@ class ConfigManager(object):
                                     node, group))
         for group in attribmap.iterkeys():
             group = group.encode('utf-8')
-            if group not in self._cfgstore['groups']:
-                self._cfgstore['groups'][group] = {'nodes': set()}
-            cfgobj = self._cfgstore['groups'][group]
+            if group not in self._cfgstore['nodegroups']:
+                self._cfgstore['nodegroups'][group] = {'nodes': set()}
+            cfgobj = self._cfgstore['nodegroups'][group]
             for attr in attribmap[group].iterkeys():
                 if attr == 'nodes':
                     newdict = set(attribmap[group][attr])
@@ -796,7 +831,7 @@ class ConfigManager(object):
                         self._do_inheritance(nodecfg, attr, node, changeset,
                                              srcgroup=group)
                         _addchange(changeset, node, attr)
-            _mark_dirtykey('groups', group, self.tenant)
+            _mark_dirtykey('nodegroups', group, self.tenant)
         self._notif_attribwatchers(changeset)
         self._bg_sync_to_file()
 
@@ -807,7 +842,7 @@ class ConfigManager(object):
         for group in groups:
                 group = group.encode('utf-8')
                 try:
-                    groupentry = self._cfgstore['groups'][group]
+                    groupentry = self._cfgstore['nodegroups'][group]
                 except KeyError:
                     continue
                 for attrib in attributes:
@@ -833,7 +868,7 @@ class ConfigManager(object):
                                                      changeset)
                                 _addchange(changeset, node, attrib)
                                 _mark_dirtykey('nodes', node, self.tenant)
-                _mark_dirtykey('groups', group, self.tenant)
+                _mark_dirtykey('nodegroups', group, self.tenant)
         self._notif_attribwatchers(changeset)
         self._bg_sync_to_file()
 
@@ -898,11 +933,11 @@ class ConfigManager(object):
     def del_groups(self, groups):
         changeset = {}
         for group in groups:
-            if group in self._cfgstore['groups']:
+            if group in self._cfgstore['nodegroups']:
                 self._sync_nodes_to_group(group=group, nodes=[],
                                           changeset=changeset)
-                del self._cfgstore['groups'][group]
-                _mark_dirtykey('groups', group, self.tenant)
+                del self._cfgstore['nodegroups'][group]
+                _mark_dirtykey('nodegroups', group, self.tenant)
         self._notif_attribwatchers(changeset)
         self._bg_sync_to_file()
 
@@ -964,10 +999,10 @@ class ConfigManager(object):
                     raise ValueError(errstr)
                 if attrname == 'groups':
                     for group in attribmap[node]['groups']:
-                        if group not in self._cfgstore['groups']:
+                        if group not in self._cfgstore['nodegroups']:
                             raise ValueError(
                                 "group {0} does not exist".format(group))
-                    if ('everything' in self._cfgstore['groups'] and
+                    if ('everything' in self._cfgstore['nodegroups'] and
                             'everything' not in attribmap[node]['groups']):
                         attribmap[node]['groups'].append('everything')
         for node in attribmap.iterkeys():
@@ -1026,18 +1061,22 @@ class ConfigManager(object):
         _load_dict_from_dbm(['globals'], rootpath + "/globals")
         _load_dict_from_dbm(['main', 'nodes'], rootpath + "/nodes")
         _load_dict_from_dbm(['main', 'users'], rootpath + "/users")
-        _load_dict_from_dbm(['main', 'groups'], rootpath + "/groups")
+        _load_dict_from_dbm(['main', 'nodegroups'], rootpath + "/nodegroups")
+        _load_dict_from_dbm(['main', 'usergroups'], rootpath + "/usergroups")
         try:
             for tenant in os.listdir(rootpath + '/tenants/'):
                 _load_dict_from_dbm(
                     ['main', tenant, 'nodes'],
                     "%s/%s/nodes" % (rootpath, tenant))
                 _load_dict_from_dbm(
-                    ['main', tenant, 'groups'],
+                    ['main', tenant, 'nodegroups'],
                     "%s/%s/groups" % (rootpath, tenant))
                 _load_dict_from_dbm(
                     ['main', tenant, 'users'],
                     "%s/%s/users" % (rootpath, tenant))
+                _load_dict_from_dbm(
+                    ['main', tenant, 'usergroups'],
+                    "%s/%s/usergroups" % (rootpath, tenant))
         except OSError:
             pass
 
@@ -1123,4 +1162,4 @@ except IOError:
 # group should get it then
 # rinse and repeat for set on node versus set on group
 # clear group attribute and assure than it becomes unset on all nodes
-# set various expressions
\ No newline at end of file
+# set various expressions
