@@ -79,7 +79,7 @@ def load_plugins():
                 pluginmap[plugin] = tmpmod
 
 
-rootcollections = ['nodes/', 'groups/', 'users/']
+rootcollections = ['nodes/', 'nodegroups/', 'users/']
 
 
 class PluginRoute(object):
@@ -151,10 +151,10 @@ def show_user(name, configmanager):
     rv = {}
     for attr in attrscheme.user.iterkeys():
         rv[attr] = None
-        if attr == 'passphrase':
+        if attr == 'password':
             if 'cryptpass' in userobj:
-                rv['passphrase'] = {'cryptvalue': True}
-            yield msg.CryptedAttributes(kv={'passphrase': rv['passphrase']},
+                rv['password'] = {'cryptvalue': True}
+            yield msg.CryptedAttributes(kv={'password': rv['password']},
                                         desc=attrscheme.user[attr][
                                             'description'])
         else:
@@ -277,7 +277,7 @@ def handle_path(path, operation, configmanager, inputdata=None):
         del pathcomponents[-1]
     if not pathcomponents:  # root collection list
         return enumerate_collections(rootcollections)
-    elif pathcomponents[0] == 'groups':
+    elif pathcomponents[0] == 'nodegroups':
         if len(pathcomponents) < 2:
             if operation == "create":
                 inputdata = msg.InputAttributes(pathcomponents, inputdata)
@@ -321,6 +321,13 @@ def handle_path(path, operation, configmanager, inputdata=None):
             return iterate_collections(configmanager.list_nodes())
         if len(pathcomponents) == 2:
             iscollection = True
+        else:
+            try:
+                routespec = nested_lookup(noderesources, pathcomponents[2:])
+            except KeyError:
+                raise exc.NotFoundException("Invalid element requested")
+            if isinstance(routespec, dict):
+                iscollection = True
         if iscollection:
             if operation == "delete":
                 return delete_node_collection(pathcomponents, configmanager)
@@ -330,10 +337,7 @@ def handle_path(path, operation, configmanager, inputdata=None):
                 raise Exception("TODO here")
         del pathcomponents[0:2]
         passvalue = None
-        try:
-            plugroute = nested_lookup(noderesources, pathcomponents).routeinfo
-        except KeyError:
-            raise exc.NotFoundException("Invalid element requested")
+        plugroute = routespec.routeinfo
         inputdata = msg.get_input_message(
             pathcomponents, operation, inputdata, (node,))
         if 'handler' in plugroute:  # fixed handler definition
